function get_offer_json(en_id, price) 
{
	var token = get_token();
	var user_name = get_user_name();
    var json = {
        "service": "supply/do_offer",
		"token": token,
		"params":
		{
			"id": en_id,
			"price": price,
		}
    };
    return json;
}

function do_offer(en_id, price) 
{
	var strMsg = prompt("请输入最新单价", price+"");
	if(strMsg == null)
	{
		return;
	}
	if(strMsg == "")
	{
		alert("价格不能为空");
		return;
	}

	var user_name=get_user_name();
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_offer_json(en_id, strMsg)),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			$("#p_"+ en_id).html(strMsg);
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function show_purchase_bill(json)
{
	$("#purchase_detail").find("tr:not(:first)").remove();
	if (!json)
	{
		return;
	}	
	data = json.data;
	if(!data || data.length == 0)
	{
		return;
	}
	g_token = json.token;
	for (var i = 0; i < data.length; i++) 
	{
		var tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}
		var id = data[i]["id"];
		var offer_price = data[i]["avg_price"];
		if(offer_price <= 0.00000001)
		{
			offer_price = data[i]["min_price"];
		}
		var td = "<td>" + (i+1) + "</td>"
				+ "<td>" + data[i]["code"] + "</td>"
				+ "<td>" + data[i]["name"] + "</td>"
				+ "<td>" + data[i]["spec"] + "</td>"
				+ "<td>" + data[i]["amount"] + "</td>"
				+ "<td>" + data[i]["unit"] + "</td>"
				+ "<td>" + data[i]["min_price"] + "</td>"
				+ "<td><span id='p_" + id + "'>" + offer_price + "</span></td>"
				+ "<td><a href='#' onclick='do_offer(" + id + "," + offer_price +")'>报价</a></td>"
				+ "<td>" + data[i]["s_code"] + "</td>"
				+ "</tr>";
		$('#purchase_detail').append(tr+td);
	}
}

function get_purchase_bill_json(purchase_id) 
{
	var token = get_token();
	var supply_id = get_user_id();
    var json = {
        "service": "supply/get_purchase_detail",
		"token": token,
		"params":
		{
			"purchase_id": purchase_id,
			"supply_id": supply_id
		}
    };
    return json;
}

function get_purchase_bill(purchase_id) 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_purchase_bill_json(purchase_id)),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_purchase_bill(json);
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function get_accept_json(purchase_id) 
{
	var token = get_token();
    var json = {
        "service": "supply/do_accept",
		"token": token,
		"params":
		{
			"purchase_id": purchase_id,
			"status_msg": "已确认 " + get_cur_time_str(),
		}
    };
    return json;
}

function do_accept(purchase_id) 
{
	if(!confirm("确认后将不可修改，是否继续？"))
	{
		return;
	}
	var user_name=get_user_name();
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_accept_json(purchase_id)),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			 $("#"+purchase_id).html("已确认");			
			 $("#A_"+purchase_id).html("已确认 ") + get_cur_time_str();	
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function get_deliver_json(purchase_id, msg) 
{
	var token = get_token();
	var user_name = get_user_name();
    var json = {
        "service": "supply/do_deliver",
		"token": token,
		"params":
		{
			"purchase_id": purchase_id,
			"status_msg": "\r\n" + msg + " " + get_cur_time_str(),
		}
    };
    return json;
}

function do_deliver(purchase_id) 
{
	var strMsg = prompt("请输入交付信息", "快递单号：");
	if(strMsg == null)
	{
		return;
	}
	if(strMsg == "")
	{
		alert("交付信息不能为空");
		return;
	}

	var user_name=get_user_name();
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_deliver_json(purchase_id, strMsg)),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			 $("#"+purchase_id).html("待结算");		
			$("#A_"+purchase_id).html(strMsg);			 
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function get_invoice_json(purchase_id, msg) 
{
	var token = get_token();

    var json = {
        "service": "supply/do_invoice",
		"token": token,
		"params":
		{
			"purchase_id": purchase_id,
			"invoices_no": msg,
		}
    };
    return json;
}

function do_invoice(purchase_id) 
{
	var strMsg = prompt("请输入发票单号", "");
	if(strMsg == null)
	{
		return;
	}
	if(strMsg == "")
	{
		alert("发票单号不能为空");
		return;
	}


	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_invoice_json(purchase_id, strMsg)),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			 $("#"+purchase_id).html("已结算");			
			 $("#A_"+purchase_id).html("发票号：" + strMsg);	
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function show_purchase(json)
{
	$("#customers").find("tr:not(:first)").remove();
	if (!json)
	{
		return;
	}	
	data = json.data;
	if(!data || data.length == 0)
	{
		$('#customers').append("<tr><td colspan='8' align='center'>没有新订单</td></tr>");
		return;
	}
	g_token = json.token;
	var user_id = get_user_id();
	for (var i = 0; i < data.length; i++) 
	{
		var tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}
		var id = data[i]["id"];
		var num = data[i]["num"];
		var status = data[i]["status"];
		var strStatus = "";
		
		if(status == 0)
		{
			strStatus =  "<span id='" + id + "'><a href='#' onclick='do_accept(" + id + ")'>确认该订单</a></span>";
		}
		else if(status == 1)
		{
			strStatus = "<span id='" + id + "'><a href='#' onclick='do_deliver(" + id + ")'>交付通知</a></span>";
		}
		else if(status == 2 || status==10)
		{
			strStatus = "<span id='" + id + "'><a href='#' onclick='do_invoice(" + id + ")'>提交发票</a></span>";
		}
		else if(status == 3)
		{
			strStatus = "已结算";
		}
		else if(status == 99)
		{
			strStatus = "已取消";
		}
		
		
		var enquiry_time = data[i]["enquiry_time"]; //计划时间
		var end_time = data[i]["end_time"]; //截止时间		
		
		strMemo = data[i]["status_msg"];
		if(data[i]["invoices_no"] != "")
		{
			strMemo += "<br>发票:" + data[i]["invoices_no"];
		}
				
		var td = "<td>" + (i+1) + "</td>"
				+ "<td><a href='#' onclick=\"show_dlg(" + id + ",'" + num + "')\">" + num + "</a>" + "</td>"
				+ "<td>" + date_part(enquiry_time) + "</td>"
				+ "<td>" + date_part(end_time) + "</td>"
				+ "<td>" + data[i]["notice"] + "</td>"
				+ "<td>" + data[i]["contactor"] + "<br>" + data[i]["mobile"] + "</td>"
				+ "<td><a href='#' onclick=\"show_dlg(" + id + ",'" + num + "')\">报价</a><br><span id='A_" + id + "'>" + strStatus + "</span></td>"		
				+ "<td>" + strMemo + "</td>"		
				+ "</tr>";
		$('#customers').append(tr+td);
	}
}

function get_sch_purchase_json() 
{
	var token = get_token();
	var user_id = get_user_id();
	var end_time = $("#e_day").val() + " 23:59:59"; //结束时间
    var json = {
        "service": "supply/list_purchase_order",
		"token": token,
		"params":
		{
			"supply_id": user_id,
			"begin_time": $("#s_day").val(),
			"end_time": end_time
		}
    };
    return json;
}

function search_purchase() 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_sch_purchase_json()),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_purchase(json);
			
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}
function show_rpt(json)
{
	if (!json)
	{
		return;
	}	
	data = json.data;
	
	g_token = json.token;
	
	$("#customers").empty();
	
	var tr = "", chart_title="采购数量统计";

	tr = "<tr>"
			+"<th width='70px'>序号</th>"
			+"<th width='100px'>物料代码</th>"
			+"<th width='150px'>物料名称</th>"
			+"<th width='180px'>规格型号</th>"
			+"<th width='70px'>单位</th>"
			+"<th width='60px'>1月</th>"
			+"<th width='60px'>2月</th>"
			+"<th width='60px'>3月</th>"
			+"<th width='60px'>4月</th>"
			+"<th width='60px'>5月</th>"
			+"<th width='60px'>6月</th>"
			+"<th width='60px'>7月</th>"
			+"<th width='60px'>8月</th>"
			+"<th width='60px'>9月</th>"
			+"<th width='60px'>10月</th>"
			+"<th width='60px'>11月</th>"
			+"<th width='60px'>12月</th>"
			+"<th width='80px'>合计数量</th>"
		+"</tr>";
	
	$('#customers').append(tr);
	
	if(!data || data.length == 0)
	{
		$('#customers').append("<tr><td colspan='18' align='center'>没有数据</td></tr>");
		rpt_chart("rpt_chart", chart_title, new Array(0,0,0,0,0,0,0,0,0,0,0,0));
		return;
	}
	
	for (var i = 0; i < data.length; i++) 
	{
		tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}

		tr += "<td>" + (i+1) + "</td>"
				+ "<td>" + data[i]["code"] + "</td>"
				+ "<td>" + data[i]["name"] + "</td>"
				+ "<td>" + data[i]["spec"] + "</td>"
				+ "<td>" + data[i]["unit"] + "</td>"
				+ "<td>" + data[i]["m1"] + "</td>"
				+ "<td>" + data[i]["m2"] + "</td>"
				+ "<td>" + data[i]["m3"] + "</td>"
				+ "<td>" + data[i]["m4"] + "</td>"
				+ "<td>" + data[i]["m5"] + "</td>"
				+ "<td>" + data[i]["m6"] + "</td>"
				+ "<td>" + data[i]["m7"] + "</td>"
				+ "<td>" + data[i]["m8"] + "</td>"
				+ "<td>" + data[i]["m9"] + "</td>"
				+ "<td>" + data[i]["m10"] + "</td>"
				+ "<td>" + data[i]["m11"] + "</td>"
				+ "<td>" + data[i]["m12"] + "</td>"
				+ "<td>" + data[i]["t_amount"] + "</td>"
			+ "</tr>";
		$('#customers').append(tr);
	}
	var sum_data = sum_cols("customers", 5, 13);
	rpt_chart("rpt_chart", chart_title, sum_data);
}

function get_rpt_purchase_json() 
{
	var token = get_token();
	var supply_id = get_user_id();
	var year = $("#rpt_year").val();
	var json = 
	{
		"service": "supply/rpt_mat",
		"token": token,
		"params":
		{
			"supply_id": supply_id,
			"year": year,
		}		
    };
	return json;
}

function rpt_purchase() 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_rpt_purchase_json()),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_rpt(json);
			
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function show_stock(json)
{
	$("#customers").find("tr:not(:first)").remove();
	if (!json)
	{
		return;
	}	
	data = json.data;
	if(!data || data.length == 0)
	{
		$('#customers').append("<tr><td colspan='8' align='center'>没有数据</td></tr>");
		return;
	}
	g_token = json.token;
	var user_id = get_user_id();
	for (var i = 0; i < data.length; i++) 
	{
		var tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}
		tr += "<td>" + (i+1) + "</td>"
				+ "<td>" + data[i]["code"] + "</td>"
				+ "<td>" + data[i]["name"] + "</td>"
				+ "<td>" + data[i]["spec"] + "</td>"
				+ "<td>" + data[i]["color"] + "</td>"
				+ "<td>" + data[i]["quantity"] + "</td>"
				+ "<td>" + data[i]["unit"] + "</td>"
				+ "<td>" + data[i]["s_code"] + "</td>"
			+ "</tr>";
		$('#customers').append(tr);
	}
}

function get_sch_stock_json() 
{
	var token = get_token();
	var user_id = get_user_id();
    var json = {
        "service": "supply/list_supply_mat",
		"token": token,
		"params":
		{
			"supply_id": user_id,
		}
    };
    return json;
}

function search_stock() 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_sch_stock_json()),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_stock(json);
			
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}
function get_file_json(id)
{
	var token = get_token();
    var json = {
        "service": "supply/get_attach",
		"token": token,
		"params":
		{
			"id": id,
		}
    };
    return JSON.stringify(json);
}

function show_file(json)
{
	$("#customers").find("tr:not(:first)").remove();
	if (!json)
	{
		return;
	}	
	data = json.data;
	if(!data || data.length == 0)
	{
		$('#customers').append("<tr><td colspan='8' align='center'>没有数据</td></tr>");
		return;
	}
	g_token = json.token;
	var user_id = get_user_id();
	for (var i = 0; i < data.length; i++) 
	{
		var tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}
		var id = data[i]["id"];
		var json_str = get_file_json(id);
		tr += "<td>" + (i+1) + "</td>"
				+ "<td>" + data[i]["code"] + "</td>"
				+ "<td>" + data[i]["name"] + "</td>"
				+ "<td>" + data[i]["spec"] + "</td>"
				+ "<td> <a href='/_NBFL_/" + data[i]["res_name"] + "?json=" + json_str + "'>" + data[i]["res_name"] + "</a></td>"
				+ "<td>" + data[i]["update_time"] + "</td>"
				+ "<td>" + data[i]["res_desc"] + "</td>"
				+ "<td> <a href='/_NBFL_/" + data[i]["res_name"] + "?json=" + json_str + "'>下载</a></td>"
			+ "</tr>";
		$('#customers').append(tr);
	}
}

function get_sch_file_json() 
{
	var token = get_token();
	var user_id = get_user_id();
    var json = {
        "service": "supply/get_attach_list",
		"token": token,
		"params":
		{
			"supply_id": user_id,
		}
    };
    return json;
}

function search_file() 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_sch_file_json()),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_file(json);
			
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}


function show_bom_mat(json,flag)
{
	$("#bom_detail").find("tr:not(:first)").remove();
	if (!json)
	{
		return;
	}	
	data = json.data;
	if(!data || data.length == 0)
	{
		$('#bom_detail').append("<tr><td colspan='8' align='center'>没有数据</td></tr>");
		return;
	}
	g_token = json.token;
	var user_id = get_user_id();
	for (var i = 0; i < data.length; i++) 
	{
		var tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}
		var id = data[i]["id"];
		var child_cnt = data[i]["child_cnt"];
		var name = data[i]["name"];
		tr += "<td>" + (i+1) + "</td>"
				+ "<td>" + data[i]["code"] + "</td>"
				+ "<td>" + data[i]["name"] + "</td>"
				+ "<td>" + data[i]["spec"] + "</td>"
				+ "<td>" + data[i]["quantity"] + "</td>"
				+ "<td>" + data[i]["unit"] + "</td>"
				+ "<td>" + data[i]["pos"] + "</td>"
				+ "<td>" + data[i]["env"] + "</td>"
				+ "<td>" + data[i]["bom_memo"] + "</td>"
			+ "</tr>";
		$('#bom_detail').append(tr);
	}
	if(flag == 1)
	{
		exportExcel('bom_detail', '物料清单');
	}
}

function get_bom_json(bom_id) 
{
	var token = get_token();
	var user_id = get_user_id();
    var json = {
        "service": "bom_share/get_bom",
		"token": token,
		"params":
		{
			"bom_id": bom_id,
		}
    };
    return json;
}


function show_bom(bom_id, flag) 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_bom_json(bom_id)),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_bom_mat(json, flag);
			
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

function show_bom_list(json)
{
	$("#customers").find("tr:not(:first)").remove();
	if (!json)
	{
		return;
	}	
	data = json.data;
	if(!data || data.length == 0)
	{
		$('#customers').append("<tr><td colspan='8' align='center'>没有数据</td></tr>");
		return;
	}
	g_token = json.token;
	var user_id = get_user_id();
	for (var i = 0; i < data.length; i++) 
	{
		var tr = "<tr>";
		if (i % 2 == 0)
		{
			tr = "<tr class='alt'>";
		}
		var id = data[i]["id"];
		var name = data[i]["name"];
		var chk_id = "C_" + id;
		tr +=	"<td><input type='checkbox' name='b_mrp' id='b_mrp' value='" + id + "'></td>"
				+ "<td>" + (i+1) +  "</td>"
				+ "<td>" + data[i]["code"] + "</td>"
				+ "<td>" + data[i]["name"] + "</td>"
				+ "<td>" + data[i]["spec"] + "</td>"
				+ "<td>" + data[i]["paper_no"] + "</td>"
				+ "<td><a href='#' onclick=\"show_dlg(" + id + ",'" + name + "')\">查看</a> - "
				+ "<a href='#' onclick=\"show_bom(" + id + ",1)\">导出</a></td>"
				+ "<td>" + data[i]["issue_time"] + "</td>"
				+ "<td><input type='text' name='b_amount' id='b_amount' size='4' value='1'></td>"	
				+ "<td>" + data[i]["bom_memo"] + "</td>"
			+ "</tr>";
		$('#customers').append(tr);
	}
}

function get_bom_list_json() 
{
	var token = get_token();
	var user_id = get_user_id();
    var json = {
        "service": "bom_share/get_bom_list",
		"token": token,
		"params":
		{
			"supply_id": user_id,
		}
    };
    return json;
}

function get_bom_list() 
{
	$.ajax(
	{
　　　　url : g_url, 　   <!-- url  :请求地址 -->  
　　　　type : 'post',　　　　　　　　<!--type ：请求类型:post/get --> 
		xhrFields: {
                withCredentials: true // 这里设置了withCredentials
            },
		async:false,
　　　　data : JSON.stringify(get_bom_list_json()),
	
	　　success:function(data)
		{
			var json = eval('(' + data + ')');
			show_bom_list(json);
			
	　　},
		error:function (request, status, error)
		{
//			alert(error);
	　　}
	});
}

